# Authors

The following people have constributed to the project (in alphabetical order):

- [Arunodhai V](https://github.com/Arunodhai), BCA student, India
- [Matt Hall](https://github.com/kwinkunks), Agile Scientific, Canada (ORCID: [0000-0002-4054-8295](https://orcid.org/0000-0002-4054-8295))
- [Diego Castañeda](https://github.com/dfcastap), Agile Scientific, Canada
- [Rob Leckenby](https://github.com/zabamund), Agile Scientific, Switzerland
- [Martin Bentley](https://github.com/mtb-za), Agile Scientific, Canada
